# eric7.Plugins.VcsPlugins.vcsMercurial.HgBackoutDialog

Module implementing a dialog to enter the data for a backout operation.

### Global Attributes

None

### Classes

HgBackoutDialog | Class implementing a dialog to enter the data for a backout operation.

### Functions

None

## HgBackoutDialog

Class implementing a dialog to enter the data for a backout operation.

### Derived from

QDialog, Ui_HgBackoutDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgBackoutDialog | Constructor
__updateOK | Private slot to update the OK button.
getParameters | Public method to retrieve the backout data.

### Static Methods

None

#### HgBackoutDialog (Constructor)

HgBackoutDialog(tagsList, branchesList, bookmarksList=None, parent=None)

Constructor

tagsList (list of str)
  list of tags
branchesList (list of str)
  list of branches
bookmarksList (list of str)
  list of bookmarks
parent (QWidget)
  parent widget

#### HgBackoutDialog.__updateOK

__updateOK()

Private slot to update the OK button.

#### HgBackoutDialog.getParameters

getParameters()

Public method to retrieve the backout data.

Return:
  tuple naming the revision, a flag indicating a merge, the commit date, the commit user and a commit message

Return Type:
  tuple of (str, bool, str, str, str)

Up